==> knative-model-5.4.2-sources.jar: annotations/io/fabric8/knative/eventing/v1/TriggerSpecFluentImpl.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl;
import java.lang.Boolean;

public class TriggerSpecFluentImpl<A extends io.fabric8.knative.eventing.v1.TriggerSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.eventing.v1.TriggerSpecFluent<A> {

    private java.lang.String broker;
    private io.fabric8.knative.eventing.v1.TriggerFilterBuilder filter;
    private io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder subscriber;

    public TriggerSpecFluentImpl() {
    }

    public TriggerSpecFluentImpl(io.fabric8.knative.eventing.v1.TriggerSpec instance) {
        this.withBroker(instance.getBroker()); 
        this.withFilter(instance.getFilter()); 
        this.withSubscriber(instance.getSubscriber()); 
    }

    public java.lang.String getBroker() {
        return this.broker;
    }

    public A withBroker(java.lang.String broker) {
        this.broker=broker; return (A) this;
    }

    public java.lang.Boolean hasBroker() {
        return this.broker != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withBroker instead.
     */
        public A withNewBroker(java.lang.String arg0) {
        return (A)withBroker(new String(arg0));
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildFilter instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.eventing.v1.TriggerFilter getFilter() {
        return this.filter!=null?this.filter.build():null;
    }

    public io.fabric8.knative.eventing.v1.TriggerFilter buildFilter() {
        return this.filter!=null?this.filter.build():null;
    }

    public A withFilter(io.fabric8.knative.eventing.v1.TriggerFilter filter) {
        _visitables.get("filter").remove(this.filter);
        if (filter!=null){ this.filter= new io.fabric8.knative.eventing.v1.TriggerFilterBuilder(filter); _visitables.get("filter").add(this.filter);} return (A) this;
    }

    public java.lang.Boolean hasFilter() {
        return this.filter != null;
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> withNewFilter() {
        return new io.fabric8.knative.eventing.v1.TriggerSpecFluentImpl.FilterNestedImpl();
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> withNewFilterLike(io.fabric8.knative.eventing.v1.TriggerFilter item) {
        return new io.fabric8.knative.eventing.v1.TriggerSpecFluentImpl.FilterNestedImpl(item);
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editFilter() {
        return withNewFilterLike(getFilter());
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editOrNewFilter() {
        return withNewFilterLike(getFilter() != null ? getFilter(): new io.fabric8.knative.eventing.v1.TriggerFilterBuilder().build());
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editOrNewFilterLike(io.fabric8.knative.eventing.v1.TriggerFilter item) {
        return withNewFilterLike(getFilter() != null ? getFilter(): item);
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildSubscriber instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.internal.pkg.apis.duck.v1.Destination getSubscriber() {
        return this.subscriber!=null?this.subscriber.build():null;
    }

    public io.fabric8.knative.internal.pkg.apis.duck.v1.Destination buildSubscriber() {
        return this.subscriber!=null?this.subscriber.build():null;
    }

    public A withSubscriber(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination subscriber) {
        _visitables.get("subscriber").remove(this.subscriber);
        if (subscriber!=null){ this.subscriber= new io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder(subscriber); _visitables.get("subscriber").add(this.subscriber);} return (A) this;
    }

    public java.lang.Boolean hasSubscriber() {
        return this.subscriber != null;
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> withNewSubscriber() {
        return new io.fabric8.knative.eventing.v1.TriggerSpecFluentImpl.SubscriberNestedImpl();
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> withNewSubscriberLike(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination item) {
        return new io.fabric8.knative.eventing.v1.TriggerSpecFluentImpl.SubscriberNestedImpl(item);
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editSubscriber() {
        return withNewSubscriberLike(getSubscriber());
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriber() {
        return withNewSubscriberLike(getSubscriber() != null ? getSubscriber(): new io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder().build());
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriberLike(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination item) {
        return withNewSubscriberLike(getSubscriber() != null ? getSubscriber(): item);
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        TriggerSpecFluentImpl that = (TriggerSpecFluentImpl) o;
        if (broker != null ? !broker.equals(that.broker) :that.broker != null) return false;
        if (filter != null ? !filter.equals(that.filter) :that.filter != null) return false;
        if (subscriber != null ? !subscriber.equals(that.subscriber) :that.subscriber != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(broker,  filter,  subscriber,  super.hashCode());
    }

    public class FilterNestedImpl<N> extends io.fabric8.knative.eventing.v1.TriggerFilterFluentImpl<io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<N>> implements io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.eventing.v1.TriggerFilterBuilder builder;

            FilterNestedImpl(io.fabric8.knative.eventing.v1.TriggerFilter item) {
                this.builder = new io.fabric8.knative.eventing.v1.TriggerFilterBuilder(this, item);
                        
            }

            FilterNestedImpl() {
                this.builder = new io.fabric8.knative.eventing.v1.TriggerFilterBuilder(this);
                        
            }

            public N and() {
                return (N) TriggerSpecFluentImpl.this.withFilter(builder.build());
            }

            public N endFilter() {
                return and();
            }
    }


    public class SubscriberNestedImpl<N> extends io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl<io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<N>> implements io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder builder;

            SubscriberNestedImpl(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination item) {
                this.builder = new io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder(this, item);
                        
            }

            SubscriberNestedImpl() {
                this.builder = new io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder(this);
                        
            }

            public N and() {
                return (N) TriggerSpecFluentImpl.this.withSubscriber(builder.build());
            }

            public N endSubscriber() {
                return and();
            }
    }


}

==> knative-model-5.7.2-sources.jar: annotations/io/fabric8/knative/eventing/v1/TriggerSpecFluentImpl.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl;
import java.lang.Boolean;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec;

public class TriggerSpecFluentImpl<A extends io.fabric8.knative.eventing.v1.TriggerSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.eventing.v1.TriggerSpecFluent<A> {

    private java.lang.String broker;
    private io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder delivery;
    private io.fabric8.knative.eventing.v1.TriggerFilterBuilder filter;
    private io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder subscriber;

    public TriggerSpecFluentImpl() {
    }

    public TriggerSpecFluentImpl(io.fabric8.knative.eventing.v1.TriggerSpec instance) {
        this.withBroker(instance.getBroker()); 
        this.withDelivery(instance.getDelivery()); 
        this.withFilter(instance.getFilter()); 
        this.withSubscriber(instance.getSubscriber()); 
    }

    public java.lang.String getBroker() {
        return this.broker;
    }

    public A withBroker(java.lang.String broker) {
        this.broker=broker; return (A) this;
    }

    public java.lang.Boolean hasBroker() {
        return this.broker != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withBroker instead.
     */
        public A withNewBroker(java.lang.String arg0) {
        return (A)withBroker(new String(arg0));
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildDelivery instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec getDelivery() {
        return this.delivery!=null?this.delivery.build():null;
    }

    public io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec buildDelivery() {
        return this.delivery!=null?this.delivery.build():null;
    }

    public A withDelivery(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec delivery) {
        _visitables.get("delivery").remove(this.delivery);
        if (delivery!=null){ this.delivery= new io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder(delivery); _visitables.get("delivery").add(this.delivery);} return (A) this;
    }

    public java.lang.Boolean hasDelivery() {
        return this.delivery != null;
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<A> withNewDelivery() {
        return new io.fabric8.knative.eventing.v1.TriggerSpecFluentImpl.DeliveryNestedImpl();
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<A> withNewDeliveryLike(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec item) {
        return new io.fabric8.knative.eventing.v1.TriggerSpecFluentImpl.DeliveryNestedImpl(item);
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<A> editDelivery() {
        return withNewDeliveryLike(getDelivery());
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<A> editOrNewDelivery() {
        return withNewDeliveryLike(getDelivery() != null ? getDelivery(): new io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder().build());
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<A> editOrNewDeliveryLike(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec item) {
        return withNewDeliveryLike(getDelivery() != null ? getDelivery(): item);
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildFilter instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.eventing.v1.TriggerFilter getFilter() {
        return this.filter!=null?this.filter.build():null;
    }

    public io.fabric8.knative.eventing.v1.TriggerFilter buildFilter() {
        return this.filter!=null?this.filter.build():null;
    }

    public A withFilter(io.fabric8.knative.eventing.v1.TriggerFilter filter) {
        _visitables.get("filter").remove(this.filter);
        if (filter!=null){ this.filter= new io.fabric8.knative.eventing.v1.TriggerFilterBuilder(filter); _visitables.get("filter").add(this.filter);} return (A) this;
    }

    public java.lang.Boolean hasFilter() {
        return this.filter != null;
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> withNewFilter() {
        return new io.fabric8.knative.eventing.v1.TriggerSpecFluentImpl.FilterNestedImpl();
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> withNewFilterLike(io.fabric8.knative.eventing.v1.TriggerFilter item) {
        return new io.fabric8.knative.eventing.v1.TriggerSpecFluentImpl.FilterNestedImpl(item);
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editFilter() {
        return withNewFilterLike(getFilter());
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editOrNewFilter() {
        return withNewFilterLike(getFilter() != null ? getFilter(): new io.fabric8.knative.eventing.v1.TriggerFilterBuilder().build());
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editOrNewFilterLike(io.fabric8.knative.eventing.v1.TriggerFilter item) {
        return withNewFilterLike(getFilter() != null ? getFilter(): item);
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildSubscriber instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.internal.pkg.apis.duck.v1.Destination getSubscriber() {
        return this.subscriber!=null?this.subscriber.build():null;
    }

    public io.fabric8.knative.internal.pkg.apis.duck.v1.Destination buildSubscriber() {
        return this.subscriber!=null?this.subscriber.build():null;
    }

    public A withSubscriber(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination subscriber) {
        _visitables.get("subscriber").remove(this.subscriber);
        if (subscriber!=null){ this.subscriber= new io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder(subscriber); _visitables.get("subscriber").add(this.subscriber);} return (A) this;
    }

    public java.lang.Boolean hasSubscriber() {
        return this.subscriber != null;
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> withNewSubscriber() {
        return new io.fabric8.knative.eventing.v1.TriggerSpecFluentImpl.SubscriberNestedImpl();
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> withNewSubscriberLike(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination item) {
        return new io.fabric8.knative.eventing.v1.TriggerSpecFluentImpl.SubscriberNestedImpl(item);
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editSubscriber() {
        return withNewSubscriberLike(getSubscriber());
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriber() {
        return withNewSubscriberLike(getSubscriber() != null ? getSubscriber(): new io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder().build());
    }

    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriberLike(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination item) {
        return withNewSubscriberLike(getSubscriber() != null ? getSubscriber(): item);
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        TriggerSpecFluentImpl that = (TriggerSpecFluentImpl) o;
        if (broker != null ? !broker.equals(that.broker) :that.broker != null) return false;
        if (delivery != null ? !delivery.equals(that.delivery) :that.delivery != null) return false;
        if (filter != null ? !filter.equals(that.filter) :that.filter != null) return false;
        if (subscriber != null ? !subscriber.equals(that.subscriber) :that.subscriber != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(broker,  delivery,  filter,  subscriber,  super.hashCode());
    }

    public class DeliveryNestedImpl<N> extends io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecFluentImpl<io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<N>> implements io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder builder;

            DeliveryNestedImpl(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec item) {
                this.builder = new io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder(this, item);
                        
            }

            DeliveryNestedImpl() {
                this.builder = new io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder(this);
                        
            }

            public N and() {
                return (N) TriggerSpecFluentImpl.this.withDelivery(builder.build());
            }

            public N endDelivery() {
                return and();
            }
    }


    public class FilterNestedImpl<N> extends io.fabric8.knative.eventing.v1.TriggerFilterFluentImpl<io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<N>> implements io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.eventing.v1.TriggerFilterBuilder builder;

            FilterNestedImpl(io.fabric8.knative.eventing.v1.TriggerFilter item) {
                this.builder = new io.fabric8.knative.eventing.v1.TriggerFilterBuilder(this, item);
                        
            }

            FilterNestedImpl() {
                this.builder = new io.fabric8.knative.eventing.v1.TriggerFilterBuilder(this);
                        
            }

            public N and() {
                return (N) TriggerSpecFluentImpl.this.withFilter(builder.build());
            }

            public N endFilter() {
                return and();
            }
    }


    public class SubscriberNestedImpl<N> extends io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl<io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<N>> implements io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder builder;

            SubscriberNestedImpl(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination item) {
                this.builder = new io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder(this, item);
                        
            }

            SubscriberNestedImpl() {
                this.builder = new io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder(this);
                        
            }

            public N and() {
                return (N) TriggerSpecFluentImpl.this.withSubscriber(builder.build());
            }

            public N endSubscriber() {
                return and();
            }
    }


}
